@@ -82,11 +82,16 @@ class TimeFrames:
         return txt
 
 
+
 class Next24hours:
 
     def __init__(self, predicted_power: Dict[datetime, LabelledWeatherForecast]):
         self.predicted_power = predicted_power
 
+    @staticmethod
+    def __round_hour(dt: datetime) -> datetime:
+        return (dt.replace(second=0, microsecond=0, minute=0, hour=dt.hour) +timedelta(hours=dt.minute//30))
+
     @staticmethod
     def of(pv_forecast: PvPowerForecast):
         now = datetime.strptime((datetime.now()).strftime("%d.%m.%Y %H") + ":00", "%d.%m.%Y %H:%S")
@@ -95,7 +100,7 @@ class Next24hours:
             if weather_forecast is not None:
                 predicted_value = pv_forecast.predict_by_weather_forecast(weather_forecast)
                 if predicted_value is not None:
-                    predicted_power[weather_forecast.time] = LabelledWeatherForecast.create(weather_forecast, predicted_value)
+                    predicted_power[Next24hours.__round_hour(weather_forecast.time)] = LabelledWeatherForecast.create(weather_forecast, predicted_value)
         return Next24hours(predicted_power)
 
     def __prediction_values(self) -> List[int]:
@@ -144,5 +149,3 @@ class Next24hours:
         return txt
 
 
-
-
